==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/libs/qmljs/qmljsviewercontext.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef VIEWERCONTEXT_H
#define VIEWERCONTEXT_H

#include "qmljs_global.h"
#include "qmljsconstants.h"

#include <QStringList>

namespace QmlJS {

class QMLJS_EXPORT ViewerContext
{
public:
    enum Flags {
        Complete,
        AddAllPathsAndDefaultSelectors,
        AddAllPaths,
        AddDefaultPaths,
        AddDefaultPathsAndSelectors
    };

    ViewerContext();
    ViewerContext(QStringList selectors, QStringList paths,
                  Language::Enum language = Language::Qml,
                  Flags flags = AddAllPaths);

    bool languageIsCompatible(Language::Enum l) const;
    void maybeAddPath(const QString &path);

    QStringList selectors;
    QStringList paths;
    Language::Enum language;
    Flags flags;
};

} // namespace QmlJS
#endif // VIEWERCONTEXT_H

==> qt-creator-opensource-src-3.3.0.zip: qt-creator-opensource-src-3.3.0/src/libs/qmljs/qmljsviewercontext.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef VIEWERCONTEXT_H
#define VIEWERCONTEXT_H

#include "qmljs_global.h"
#include "qmljsconstants.h"
#include "qmljsdialect.h"

#include <QStringList>

namespace QmlJS {

class QMLJS_EXPORT ViewerContext
{
public:
    enum Flags {
        Complete,
        AddAllPathsAndDefaultSelectors,
        AddAllPaths,
        AddDefaultPaths,
        AddDefaultPathsAndSelectors
    };

    ViewerContext();
    ViewerContext(QStringList selectors, QStringList paths,
                  Dialect language = Dialect::Qml,
                  Flags flags = AddAllPaths);

    bool languageIsCompatible(Dialect l) const;
    void maybeAddPath(const QString &path);

    QStringList selectors;
    QStringList paths;
    Dialect language;
    Flags flags;
};

} // namespace QmlJS
#endif // VIEWERCONTEXT_H
